==> cactoos_0.48.orig.tar.gz: cactoos-0.48/src/test/java/org/cactoos/text/ConctatenatedTest.java <==
/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2017-2020 Yegor Bugayenko
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package org.cactoos.text;

import org.cactoos.iterable.IterableOf;
import org.junit.jupiter.api.Test;
import org.llorllale.cactoos.matchers.Assertion;
import org.llorllale.cactoos.matchers.TextIs;

/**
 * Test case for {@link Concatenated}.
 * @since 0.47
 */
@SuppressWarnings("PMD.AvoidDuplicateLiterals")
final class ConctatenatedTest {

    @Test
    void contatenateText() {
        new Assertion<>(
            "Must contcatenate single text",
            new Concatenated(new TextOf("bar")),
            new TextIs("bar")
        ).affirm();
    }

    @Test
    void contatenateTexts() {
        new Assertion<>(
            "Must contcatenate multi texts",
            new Concatenated(new TextOf("abc"), new TextOf("xyz")),
            new TextIs("abcxyz")
        ).affirm();
    }

    @Test
    void concatenateIterables() {
        new Assertion<>(
            "Must concatenate iterables",
            new Concatenated(new IterableOf<>(new TextOf("foo"), new TextOf("foo1"))),
            new TextIs("foofoo1")
        ).affirm();
    }
}

==> cactoos_0.49.orig.tar.gz: cactoos-0.49/src/test/java/org/cactoos/text/ConctatenatedTest.java <==
/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2017-2020 Yegor Bugayenko
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package org.cactoos.text;

import org.cactoos.iterable.IterableOf;
import org.junit.jupiter.api.Test;
import org.llorllale.cactoos.matchers.Assertion;
import org.llorllale.cactoos.matchers.TextIs;

/**
 * Test case for {@link Concatenated}.
 * @since 0.47
 */
@SuppressWarnings("PMD.AvoidDuplicateLiterals")
final class ConctatenatedTest {

    @Test
    void contatenateText() {
        new Assertion<>(
            "Must contcatenate single text",
            new Concatenated(new TextOf("bar")),
            new TextIs("bar")
        ).affirm();
    }

    @Test
    void contatenateTexts() {
        new Assertion<>(
            "Must contcatenate multi texts",
            new Concatenated(new TextOf("abc"), new TextOf("xyz")),
            new TextIs("abcxyz")
        ).affirm();
    }

    @Test
    void concatenateIterables() {
        new Assertion<>(
            "Must concatenate iterables",
            new Concatenated(new IterableOf<>(new TextOf("foo"), new TextOf("foo1"))),
            new TextIs("foofoo1")
        ).affirm();
    }

    @Test
    void contatenateString() {
        new Assertion<>(
            "Must contcatenate single string",
            new Concatenated("bar"),
            new TextIs("bar")
        ).affirm();
    }

    @Test
    void contatenateStrings() {
        new Assertion<>(
            "Must contcatenate multi strings",
            new Concatenated("abc", "xyz"),
            new TextIs("abcxyz")
        ).affirm();
    }
}
